==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/APPROVERFORRCAPPROVALLISTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour APPROVERFORRCAPPROVALLISTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="APPROVERFORRCAPPROVALLISTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVALLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APPROVERFORRCAPPROVALLISTID_Type", propOrder = {
    "approvallistid",
    "approver"
})
public class APPROVERFORRCAPPROVALLISTID_Type {

    @XmlElement(name = "APPROVALLISTID", required = true)
    protected APPROVALLISTID_Type approvallistid;
    @XmlElement(name = "APPROVER", required = true)
    protected USERID_Type approver;

    /**
     * Obtient la valeur de la propriété approvallistid.
     * 
     * @return
     *     possible object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public APPROVALLISTID_Type getAPPROVALLISTID() {
        return approvallistid;
    }

    /**
     * Définit la valeur de la propriété approvallistid.
     * 
     * @param value
     *     allowed object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public void setAPPROVALLISTID(APPROVALLISTID_Type value) {
        this.approvallistid = value;
    }

    /**
     * Obtient la valeur de la propriété approver.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVER() {
        return approver;
    }

    /**
     * Définit la valeur de la propriété approver.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVER(USERID_Type value) {
        this.approver = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/APPROVERFORRCAPPROVALLISTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APPROVERFORRCAPPROVALLISTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APPROVERFORRCAPPROVALLISTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVALLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APPROVERFORRCAPPROVALLISTID_Type", propOrder = {
    "approvallistid",
    "approver"
})
public class APPROVERFORRCAPPROVALLISTID_Type {

    @XmlElement(name = "APPROVALLISTID", required = true)
    protected APPROVALLISTID_Type approvallistid;
    @XmlElement(name = "APPROVER", required = true)
    protected USERID_Type approver;

    /**
     * Gets the value of the approvallistid property.
     * 
     * @return
     *     possible object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public APPROVALLISTID_Type getAPPROVALLISTID() {
        return approvallistid;
    }

    /**
     * Sets the value of the approvallistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link APPROVALLISTID_Type }
     *     
     */
    public void setAPPROVALLISTID(APPROVALLISTID_Type value) {
        this.approvallistid = value;
    }

    /**
     * Gets the value of the approver property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVER() {
        return approver;
    }

    /**
     * Sets the value of the approver property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVER(USERID_Type value) {
        this.approver = value;
    }

}
